<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Copia il colore %1 negli appunti</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin Picker è un tool per rilevare i colori. I codici RGB e HEX del colore selezionato vengono rilevati e salvati negli appunti.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>Deepin Picker</source>
        <translation>Deepin Picker</translation>
    </message>
</context>
</TS>
